@@ -15,7 +15,8 @@ from .exceptions import FileSkipped, ISortError, UnsupportedEncoding
 from .format import create_terminal_printer
 from .logo import ASCII_ART
 from .profiles import profiles
-from .settings import VALID_PY_TARGETS, Config
+from .settings import VALID_PY_TARGETS, Config, find_all_configs
+from .utils import Trie
 from .wrap_modes import WrapModes
 
 DEPRECATED_SINGLE_DASH_ARGS = {
@@ -119,7 +120,7 @@ def _print_hard_fail(
 ) -> None:
     """Fail on unrecoverable exception with custom message."""
     message = message or (
-        f"Unrecoverable exception thrown when parsing {offending_file or ''}!"
+        f"Unrecoverable exception thrown when parsing {offending_file or ''}! "
         "This should NEVER happen.\n"
         "If encountered, please open an issue: https://github.com/PyCQA/isort/issues/new"
     )
@@ -207,8 +208,8 @@ def _build_arg_parser() -> argparse.ArgumentParser:
     )
     general_group.add_argument(
         "--overwrite-in-place",
-        help="Tells isort to overwrite in place using the same file handle."
-        "Comes at a performance and memory usage penalty over it's standard "
+        help="Tells isort to overwrite in place using the same file handle. "
+        "Comes at a performance and memory usage penalty over its standard "
         "approach but ensures all file flags and modes stay unchanged.",
         dest="overwrite_in_place",
         action="store_true",
@@ -223,7 +224,7 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         "--show-files",
         dest="show_files",
         action="store_true",
-        help="See the files isort will be ran against with the current config options.",
+        help="See the files isort will be run against with the current config options.",
     )
     general_group.add_argument(
         "--df",
@@ -259,6 +260,22 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         help="Explicitly set the settings path or file instead of auto determining "
         "based on file location.",
     )
+    general_group.add_argument(
+        "--cr",
+        "--config-root",
+        dest="config_root",
+        help="Explicitly set the config root for resolving all configs. When used "
+        "with the --resolve-all-configs flag, isort will look at all sub-folders "
+        "in this config root to resolve config files and sort files based on the "
+        "closest available config(if any)",
+    )
+    general_group.add_argument(
+        "--resolve-all-configs",
+        dest="resolve_all_configs",
+        action="store_true",
+        help="Tells isort to resolve the configs for all sub-directories "
+        "and sort files in terms of its closest config files.",
+    )
     general_group.add_argument(
         "--profile",
         dest="profile",
@@ -276,7 +293,7 @@ def _build_arg_parser() -> argparse.ArgumentParser:
     general_group.add_argument(
         "-j",
         "--jobs",
-        help="Number of files to process in parallel.",
+        help="Number of files to process in parallel. Negative value means use number of CPUs.",
         dest="jobs",
         type=int,
         nargs="?",
@@ -305,6 +322,12 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         dest="format_success",
         help="Override the format used to print success.",
     )
+    general_group.add_argument(
+        "--sort-reexports",
+        dest="sort_reexports",
+        action="store_true",
+        help="Automatically sort all re-exports (module level __all__ collections)",
+    )
 
     target_group.add_argument(
         "files", nargs="*", help="One or more Python source files that need their imports sorted."
@@ -346,7 +369,7 @@ def _build_arg_parser() -> argparse.ArgumentParser:
     target_group.add_argument(
         "--extend-skip-glob",
         help="Additional files that isort should skip over (extending --skip-glob).",
-        dest="skip_glob",
+        dest="extend_skip_glob",
         action="append",
     )
     target_group.add_argument(
@@ -355,7 +378,7 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         action="store_true",
         dest="skip_gitignore",
         help="Treat project as a git repository and ignore files listed in .gitignore."
-        "\nNOTE: This requires git to be installed and accesible from the same shell as isort.",
+        "\nNOTE: This requires git to be installed and accessible from the same shell as isort.",
     )
     target_group.add_argument(
         "--ext",
@@ -363,13 +386,13 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         "--supported-extension",
         dest="supported_extensions",
         action="append",
-        help="Specifies what extensions isort can be ran against.",
+        help="Specifies what extensions isort can be run against.",
     )
     target_group.add_argument(
         "--blocked-extension",
         dest="blocked_extensions",
         action="append",
-        help="Specifies what extensions isort can never be ran against.",
+        help="Specifies what extensions isort can never be run against.",
     )
     target_group.add_argument(
         "--dont-follow-links",
@@ -386,7 +409,7 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         "--allow-root",
         action="store_true",
         default=False,
-        help="Tells isort not to treat / specially, allowing it to be ran against the root dir.",
+        help="Tells isort not to treat / specially, allowing it to be run against the root dir.",
     )
 
     output_group.add_argument(
@@ -462,6 +485,7 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         "--ff",
         "--from-first",
         dest="from_first",
+        action="store_true",
         help="Switches the typical ordering preference, "
         "showing from imports first then straight ones.",
     )
@@ -483,6 +507,9 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         dest="indent",
         type=str,
     )
+    output_group.add_argument(
+        "--lbi", "--lines-before-imports", dest="lines_before_imports", type=int
+    )
     output_group.add_argument(
         "--lai", "--lines-after-imports", dest="lines_after_imports", type=int
     )
@@ -687,6 +714,12 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         dest="star_first",
         action="store_true",
     )
+    output_group.add_argument(
+        "--split-on-trailing-comma",
+        help="Split imports list followed by a trailing comma into VERTICAL_HANGING_INDENT mode",
+        dest="split_on_trailing_comma",
+        action="store_true",
+    )
 
     section_group.add_argument(
         "--sd",
@@ -699,9 +732,9 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         "--os",
         dest="only_sections",
         action="store_true",
-        help="Causes imports to be sorted based on their sections like STDLIB,THIRDPARTY etc. "
+        help="Causes imports to be sorted based on their sections like STDLIB, THIRDPARTY, etc. "
         "Within sections, the imports are ordered by their import style and the imports with "
-        "same style maintain their relative positions.",
+        "the same style maintain their relative positions.",
     )
     section_group.add_argument(
         "--ds",
@@ -777,7 +810,8 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         dest="src_paths",
         action="append",
         help="Add an explicitly defined source path "
-        "(modules within src paths have their imports automatically categorized as first_party).",
+        "(modules within src paths have their imports automatically categorized as first_party)."
+        " Glob expansion (`*` and `**`) is supported for this option.",
     )
     section_group.add_argument(
         "-b",
@@ -800,7 +834,7 @@ def _build_arg_parser() -> argparse.ArgumentParser:
         help="Force isort to recognize a module as part of Python's internal future compatibility "
         "libraries. WARNING: this overrides the behavior of __future__ handling and therefore"
         " can result in code that can't execute. If you're looking to add dependencies such "
-        "as six a better option is to create a another section below --future using custom "
+        "as six, a better option is to create another section below --future using custom "
         "sections. See: https://github.com/PyCQA/isort#custom-sections-and-ordering and the "
         "discussion here: https://github.com/PyCQA/isort/issues/1463.",
     )
@@ -1069,10 +1103,15 @@ def main(argv: Optional[Sequence[str]] = None, stdin: Optional[TextIOWrapper] =
     stream_filename = config_dict.pop("filename", None)
     ext_format = config_dict.pop("ext_format", None)
     allow_root = config_dict.pop("allow_root", None)
+    resolve_all_configs = config_dict.pop("resolve_all_configs", False)
     wrong_sorted_files = False
     all_attempt_broken = False
     no_valid_encodings = False
 
+    config_trie: Optional[Trie] = None
+    if resolve_all_configs:
+        config_trie = find_all_configs(config_dict.pop("config_root", "."))
+
     if "src_paths" in config_dict:
         config_dict["src_paths"] = {
             Path(src_path).resolve() for src_path in config_dict.get("src_paths", ())
@@ -1160,6 +1199,7 @@ def main(argv: Optional[Sequence[str]] = None, stdin: Optional[TextIOWrapper] =
                     ask_to_apply=ask_to_apply,
                     write_to_stdout=write_to_stdout,
                     extension=ext_format,
+                    config_trie=config_trie,
                 ),
                 file_names,
             )
@@ -1174,6 +1214,7 @@ def main(argv: Optional[Sequence[str]] = None, stdin: Optional[TextIOWrapper] =
                     show_diff=show_diff,
                     write_to_stdout=write_to_stdout,
                     extension=ext_format,
+                    config_trie=config_trie,
                 )
                 for file_name in file_names
             )
@@ -1204,8 +1245,9 @@ def main(argv: Optional[Sequence[str]] = None, stdin: Optional[TextIOWrapper] =
             if config.verbose:
                 for was_skipped in skipped:
                     print(
-                        f"{was_skipped} was skipped as it's listed in 'skip' setting"
-                        " or matches a glob in 'skip_glob' setting"
+                        f"{was_skipped} was skipped as it's listed in 'skip' setting, "
+                        "matches a glob in 'skip_glob' setting, or is in a .gitignore file with "
+                        "--skip-gitignore enabled."
                     )
             print(f"Skipped {num_skipped} files")
 
