@@ -36,12 +36,8 @@ def test_plone(tmpdir):
 
 
 def test_pandas(tmpdir):
-    # Need to limit extensions as isort has just made sorting pxd the default, and pandas
-    # will have not picked it up yet
-    # TODO: Remove below line as soon as these files are sorted on the mainline pandas project
     git_clone("https://github.com/pandas-dev/pandas.git", tmpdir)
-    limit_extensions = ("--ext", "py", "--ext", "pyi", "--ext", "pyx")
-    run_isort((str(tmpdir / "pandas"), "--skip", "__init__.py", *limit_extensions))
+    run_isort((str(tmpdir / "pandas"), "--skip", "__init__.py"))
 
 
 def test_fastapi(tmpdir):
@@ -49,11 +45,6 @@ def test_fastapi(tmpdir):
     run_isort([str(tmpdir / "fastapi")])
 
 
-def test_zulip(tmpdir):
-    git_clone("https://github.com/zulip/zulip.git", tmpdir)
-    run_isort((str(tmpdir), "--skip", "__init__.pyi"))
-
-
 def test_habitat_lab(tmpdir):
     git_clone("https://github.com/facebookresearch/habitat-lab.git", tmpdir)
     run_isort([str(tmpdir)])
@@ -83,7 +74,19 @@ def test_websockets(tmpdir):
 
 def test_airflow(tmpdir):
     git_clone("https://github.com/apache/airflow.git", tmpdir)
-    run_isort([str(tmpdir), "--skip-glob", "*/_vendor/*"])
+    run_isort(
+        [
+            str(tmpdir),
+            "--skip-glob",
+            "*.pyi",
+            "--skip",
+            "tests",
+            "--skip",
+            "docker_tests",
+            "--skip",
+            "docs",
+        ]
+    )
 
 
 def test_typeshed(tmpdir):
@@ -97,13 +100,19 @@ def test_typeshed(tmpdir):
             "scripts",
             "--skip",
             f"{tmpdir}/third_party/2and3/yaml/__init__.pyi",
+            "--skip",
+            "builtins.pyi",
+            "--skip",
+            "ast.pyi",
+            "--skip",
+            f"{tmpdir}/stdlib/venv/__init__.pyi",
         )
     )
 
 
 def test_pylint(tmpdir):
     git_clone("https://github.com/PyCQA/pylint.git", tmpdir)
-    run_isort([str(tmpdir)])
+    run_isort([str(tmpdir), "--skip", "bad.py"])
 
 
 def test_poetry(tmpdir):
@@ -114,7 +123,18 @@ def test_poetry(tmpdir):
 def test_hypothesis(tmpdir):
     git_clone("https://github.com/HypothesisWorks/hypothesis.git", tmpdir)
     run_isort(
-        (str(tmpdir), "--skip", "tests", "--profile", "black", "--ca", "--project", "hypothesis")
+        (
+            str(tmpdir),
+            "--skip",
+            "tests",
+            "--profile",
+            "black",
+            "--ca",
+            "--project",
+            "hypothesis",
+            "--project",
+            "hypothesistooling",
+        )
     )
 
 
@@ -140,7 +160,23 @@ def test_attrs(tmpdir):
 
 def test_datadog_integrations_core(tmpdir):
     git_clone("https://github.com/DataDog/integrations-core.git", tmpdir)
-    run_isort([str(tmpdir), "--skip", "docs"])
+    run_isort(
+        [
+            str(tmpdir),
+            "--skip",
+            "ddev",
+            "--skip",
+            "docs",
+            "--skip-glob",
+            ".*",
+            "--skip-glob",
+            "*/datadog_checks/dev/tooling/signing.py",
+            "--skip-glob",
+            "*/datadog_checks/dev/tooling/templates/*",
+            "--skip-glob",
+            "*/datadog_checks/*/vendor/*",
+        ]
+    )
 
 
 def test_pyramid(tmpdir):
@@ -163,4 +199,4 @@ def test_dobby(tmpdir):
 
 def test_zope(tmpdir):
     git_clone("https://github.com/zopefoundation/Zope.git", tmpdir)
-    run_isort([str(tmpdir)])
+    run_isort([str(tmpdir), "--skip", "util.py"])
